@@ -8,7 +8,7 @@ from .datapack.headers import main as headers_main
 from .resource_pack.check_unused_textures import main as check_unused_textures_main
 import shutil
 
-def main(config: dict, user_code: callable|None):
+def main(config: dict, user_code: callable):
 
 	# For every file in the merge folder, copy it to the build folder (with append content)
 	print()
